package adminkindboxreqhandler

import (
	"net/http"
	"strconv"

	param "git.gocasts.ir/ebhomengo/niki/param/admin/kind_box_req"
	errmsg "git.gocasts.ir/ebhomengo/niki/pkg/err_msg"
	httpmsg "git.gocasts.ir/ebhomengo/niki/pkg/http_msg"
	"github.com/labstack/echo/v4"
)

// Reject godoc
// @Summary      Reject a kindboxreq by admin
// @Tags         KindBoxReq
// @Accept       json
// @Produce      json
// @Param 		 id path int true "KindBoxReq id"
// @Param 		 Request body param.KindBoxReqRejectRequest true "KindBoxReq Reject Request Body"
// @Success      200  {object}  param.KindBoxReqRejectResponse
// @Failure      400  {string}  "Bad request"
// @Security 	 AuthBearerAdmin
// @Router       /admin/kindboxreqs/reject-kind-box-req/{id} [patch].
func (h Handler) Reject(c echo.Context) error {
	var req param.KindBoxReqRejectRequest
	if bErr := c.Bind(&req); bErr != nil {
		return echo.NewHTTPError(http.StatusBadRequest)
	}
	num, cErr := strconv.ParseUint(c.Param("id"), 10, 64)
	if cErr != nil {
		return c.JSON(http.StatusBadRequest, errmsg.ErrorMsgInvalidInput)
	}
	req.ID = uint(num)
	if fieldErrors, err := h.adminKindBoxReqVld.ValidateRejectRequest(req); err != nil {
		msg, code := httpmsg.Error(err)

		return c.JSON(code, echo.Map{
			"message": msg,
			"errors":  fieldErrors,
		})
	}

	resp, sErr := h.adminKindBoxReqSvc.Reject(c.Request().Context(), req)
	if sErr != nil {
		msg, code := httpmsg.Error(sErr)

		return echo.NewHTTPError(code, msg)
	}

	return c.JSON(http.StatusOK, resp)
}
